@@ -28,6 +28,7 @@ import javax.validation.ConstraintViolation;
 
 import org.junit.Before;
 import org.junit.BeforeClass;
+import org.junit.ClassRule;
 import org.junit.Rule;
 import org.junit.Test;
 import org.mockito.InjectMocks;
@@ -42,6 +43,7 @@ import org.ovirt.engine.core.bll.network.macpool.MacPoolPerCluster;
 import org.ovirt.engine.core.bll.network.vm.ExternalVmMacsFinder;
 import org.ovirt.engine.core.bll.utils.VmDeviceUtils;
 import org.ovirt.engine.core.bll.validator.ImportValidator;
+import org.ovirt.engine.core.bll.validator.VmNicMacsUtils;
 import org.ovirt.engine.core.common.action.ImportVmParameters;
 import org.ovirt.engine.core.common.businessentities.ArchitectureType;
 import org.ovirt.engine.core.common.businessentities.BusinessEntitiesDefinitions;
@@ -68,6 +70,7 @@ import org.ovirt.engine.core.common.utils.ValidationUtils;
 import org.ovirt.engine.core.common.utils.VmDeviceType;
 import org.ovirt.engine.core.compat.Guid;
 import org.ovirt.engine.core.compat.Version;
+import org.ovirt.engine.core.utils.MockConfigRule;
 import org.ovirt.engine.core.utils.RandomUtils;
 import org.ovirt.engine.core.utils.RandomUtilsSeedingRule;
 import org.ovirt.engine.core.vdsbroker.vdsbroker.VdsProperties;
@@ -87,6 +90,9 @@ public class ImportVmCommandTest extends BaseCommandTest {
     @Mock
     private ExternalVmMacsFinder externalVmMacsFinder;
 
+    @Mock
+    private VmNicMacsUtils vmNicMacsUtils;
+
     @InjectMocks
     private VmDeviceUtils vmDeviceUtils;
 
@@ -94,6 +100,9 @@ public class ImportVmCommandTest extends BaseCommandTest {
     @InjectMocks
     private ImportVmCommand<ImportVmParameters> cmd = new ImportVmCommand<>(createParameters(), null);
 
+    @ClassRule
+    public static MockConfigRule mcr = new MockConfigRule();
+
     @BeforeClass
     public static void setUpOsRepository() {
         // init the injector with the osRepository instance
